#
# spec file for package scilab
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 5
%define soname lib%{name}%{sover}
#%define beta_version 5.5.0-beta-1

Name:           scilab
Summary:        High Level Programming Language/Numerical Analysis Software
License:        CECILL-2.0 and BSD-3-Clause
Group:          Productivity/Scientific/Math
Version:        5.5.2
Release:        6.16
Url:            http://www.scilab.org
# FOR STABLE RELEASE
Source0:        http://www.scilab.org/download/%{version}/%{name}-%{version}-src.tar.gz
# FOR BETA RELEASE
#Source0:        http://www.scilab.org/download/%{beta_version}/%{name}-%{beta_version}-src.tar.gz
Source1:        %{name}-rpmlintrc

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Bug 64307 - Use dynamic stack on 32-bit to avoid miscompilation
# http://bugzilla.scilab.org/show_bug.cgi?id=12625
Patch2:         %{name}-0002-always-use-dynamic-stack.patch
# PATCH-FIX-UPSTREAM scilab-fix-64bit-portability-issue.patch badshah400@gmail.com -- Fix compiler warnings w.r.t 64bit portability
Patch3:         scilab-fix-64bit-portability-issue.patch
# PATCH-FIX-OPENSUSE scilab-special-jarnames.patch badshah400@gmail.com -- Adapt configure script for a few java library names peculiar to openSUSE
Patch5:         scilab-special-jarnames.patch
# PATCH-FIX-UPSTREAM scilab-build-with-xmlgraphics-commons-2_0.patch badshah400@gmail.com -- Fix compilation with xmlgraphics-commons >= 2.0
Patch6:         scilab-build-with-xmlgraphics-commons-2_0.patch
# PATCH-FIX-OPENSUSE scilab-0003-fix-xcos-desktop.patch sfalken@opensuse.org -- Change Desktop categories in xcos.desktop to clear brp-check-suse failure
Patch7:         %{name}-0003-fix-desktop-categories.patch
# PATCH-FIX-UPSTREAM scilab-build-with-jogl-gluegen-2.3.patch badshah400@gmail.com -- Make scilab build with jogl and gluegen >= 2.3.0
Patch8:         scilab-build-with-jogl-2.3.patch
# PATCH-FIX-OPENSUSE scilab-timestamp.patch olaf@aepfle.de -- Remove timestamps from binaries
Patch9:         scilab-timestamp.patch
# PATCH-FIX-UPSTREAM scilab-batik-1.8.patch idoenmez@suse.de -- Fix build with batik 1.8
Patch10:        scilab-batik-1.8.patch
# to sync with java-1_8_0-openjdk sr #365892
Patch11:        scilab_ppc64le_java_archinstall_changed.patch
# PATCH-FIX-UPSTREAM scilab-build-with-fop-2_1.patch badshah400@gmail.com -- Fix build failures when using xmlgraphics-fop >= 2.1 which has now landed in openSUSE:Factory; patch taken from upstream
Patch12:        scilab-build-with-fop-2_1.patch
# PATCH-FIX-UPSTREAM scilab-self-closing-br.patch badshah400@gmail.com -- Fix build failures with updated javadoc
Patch13:        scilab-self-closing-br.patch
# PATCH-FIX-UPSTREAM scilab-hdf5-1_10-compat.patch badshah400@gmail.com -- Adapt to updated HDF5 (>= 1.10) API 
Patch14:        scilab-hdf5-1_10-compat.patch
# exclude ppc64 build as long as upstream open http://bugzilla.scilab.org/show_bug.cgi?id=13826
ExcludeArch:    ppc64
# Dependencies are extracted from :
# "http://wiki.scilab.org/Dependencies of Scilab 5.X"
# Mandatory
BuildRequires:  asm2
BuildRequires:  f2c
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran

## for dynamic link features
Requires:       gcc
Requires:       gcc-c++
Requires:       gcc-fortran
# Core
BuildRequires:  libcurl-devel
BuildRequires:  libxml2-devel
BuildRequires:  ncurses-devel
BuildRequires:  pcre-devel

# Numerical libraries
# see "http://wiki.scilab.org/Linalg performances"
BuildRequires:  arpack-ng-devel
BuildRequires:  blas-devel
BuildRequires:  lapack-devel
BuildRequires:  libarpack2

# GUI/Console
BuildRequires:  ant
BuildRequires:  java-devel >= 1.8.0
BuildRequires:  jpackage-utils

BuildRequires:  Mesa-devel
BuildRequires:  flexdock
BuildRequires:  jogl2 >= 2.2.4

Requires:       flexdock
Requires:       jogl2 >= 2.2.4

BuildRequires:  jrosetta
Requires:       jrosetta

BuildRequires:  apache-commons-logging
BuildRequires:  batik
BuildRequires:  fop
BuildRequires:  javahelp2
BuildRequires:  jeuclid
BuildRequires:  jgraphx >= 2.0.0.1
BuildRequires:  jlatexmath
BuildRequires:  jlatexmath-fop
BuildRequires:  xml-commons-jaxp-1.3-apis
BuildRequires:  xmlgraphics-commons
BuildRequires:  xmlgraphics-fop

Requires:       apache-commons-logging
Requires:       batik
Requires:       fop
Requires:       javahelp2
Requires:       jeuclid
Requires:       jgraphx >= 2.0.0.1
Requires:       jlatexmath
Requires:       jlatexmath-fop
Requires:       xmlgraphics-commons
Requires:       xmlgraphics-fop

# TCL/TK features
BuildRequires:  tcl-devel
BuildRequires:  tk-devel

Requires:       bwidget
Requires:       tcl
Requires:       tk

# Modelica
BuildRequires:  ocaml
BuildRequires:  ocaml(ocaml.opt)

# Documentation
BuildRequires:  saxon9
Requires:       saxon9
#BuildRequires:  docbook-style-xsl
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  liberation-fonts
# make doc now requires access to display
BuildRequires:  Mesa-libGL-devel
BuildRequires:  xorg-x11-server
%define         X_display         ":98"

# QA tests and validation
BuildRequires:  ant-junit
# FIXME: Disable until cobertura and checkstyle builds for >= openSUSE 13.1 are fixed
%if 0%{?suse_version} <= 1230
BuildRequires:  checkstyle
BuildRequires:  cobertura
%endif
BuildRequires:  junit4

# All optional dependencies are needed to provide a full-featured Scilab
BuildRequires:  fftw-devel
BuildRequires:  gettext-devel
BuildRequires:  hdf5-devel
BuildRequires:  libmatio-devel
BuildRequires:  suitesparse-devel

# hdf5 does not bump soname but check at runtime
Requires:       hdf5 = %{_hdf5_version}

# Specific dependencies for packaging purpose
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes

# scilab parts
Requires:       scilab-devel = %{version}
Requires:       scilab-modules = %{version}

Recommends:     scilab-lang = %{version}

Requires(post): shared-mime-info
Requires(postun): shared-mime-info
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
Requires(post): hicolor-icon-theme
Requires(postun): hicolor-icon-theme

%description
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

%package -n     %{soname}
Summary:        Scientific software package for numerical computations (shared libraries)
Group:          Development/Libraries/Other

%description -n %{soname}
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provides the shared libraries required by scilab and scilab-devel.


%package        devel
Summary:        Scientific software package for numerical computations (include files)
Group:          Development/Languages/C and C++
Requires:       %{soname} = %{version}
Requires:       libSM-devel
Requires:       libxml2-devel
Requires:       ncurses-devel
Requires:       pcre-devel
Requires:       pkg-config
Requires:       tcl-devel
Requires:       tk-devel

%description    devel
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provides files for coding in C/C++ with Scilab.

%package        modules
Summary:        Scilab modules
Group:          Productivity/Scientific/Other
BuildArch:      noarch
Requires:       scilab = %{version}
Recommends:     scilab-modules-doc = %{version}

%description    modules
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provides Scilab modules.

%package        modules-doc
Summary:        Documentation for Scilab modules
Group:          Documentation/Other
BuildArch:      noarch
Requires:       %{name} = %{version}
Recommends:     %{name}-modules-doc-lang = %{version}

%description    modules-doc
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provides documentation files for Scilab modules.

%package        tests
Summary:        Provides test files for Scilab
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       %{name} = %{version}
# Requires:       testng

%description    tests
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provides test files for Scilab.

%lang_package
%lang_package -n %{name}-modules-doc

%prep
%setup -q

%patch1 -p1
# PATCH5 and PATCH13 have to be applied before PATCH2; all affect ./configure
%patch5 -p1
%patch2 -p1
%patch3 -p1

# Only > 13.2 and Leap have xmlgraphics-commons > 2.0
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
%patch6 -p1
%endif
%patch7 -p1
%patch8 -p1
%patch9 -p1
%if 0%{?suse_version} > 1320
%patch10 -p1
%patch11 -p1
%patch12 -p1
%endif
%patch13 -p1
%patch14 -p1

# Fix Class-Path in manifest
sed -i '/name="Class-Path"/d' build.incl.xml
sed -i '/name="Class-Path"/d' modules/javasci/build.xml
sed -i '/name="Class-Path"/d' modules/scirenderer/build.xml

%build
%configure \
    --disable-static-system-lib \
    --without-umfpack \
    --without-emf

make

export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
sleep 5
make doc

%install
make install DESTDIR=%{buildroot}

# Install .conf file so that ldconfig can find shared libs in non-std location
mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf

# remove docs
rm -rf %{buildroot}%{_datadir}/scilab/ACK*
rm -rf %{buildroot}%{_datadir}/scilab/CHANGES*
rm -rf %{buildroot}%{_datadir}/scilab/COPYING*
rm -rf %{buildroot}%{_datadir}/scilab/README*
rm -rf %{buildroot}%{_datadir}/scilab/RELEASE*
rm -rf %{buildroot}%{_datadir}/scilab/Readme_Visual.txt
rm -rf %{buildroot}%{_datadir}/scilab/license.txt

# Remove more advanced repl, user should use CLI options instead
rm -fr %{buildroot}%{_datadir}/applications/%{name}-*.desktop

# Fix categories and install .desktop files
for i in scilab scinotes xcos; \
do
  desktop-file-install \
    --dir=%{buildroot}%{_datadir}/applications \
    desktop/$i.desktop;
done

%find_lang %{name} %{?no_lang_C}

# Remove la files
rm -fr %{buildroot}%{_libdir}/%{name}/*.la

# Add localized help files to scilab-doc.lang
# adapted from find-lang.sh
# always provide the english help to handle missing localized help pages
find %{buildroot}%{_datadir}/%{name}/modules/helptools/jar -type f -o -type l|sed '
s:'"%{buildroot}"'::
s:\(.*/'"%{name}"'_\)\([^\._]\+\)\(.*\.jar$\):%lang(\2) \1\2\3:
s:^\([^%].*\)::
s:%lang(en) ::
s:%lang(C) ::
/^$/d' |tee %{name}-modules-doc.lang
# Remove en localization doc files from lang package; bundle these in %{name}-modules-doc directly
sed -i '/scilab_en_US_help.jar/d' %{name}-modules-doc.lang
sed -i '/scilab_images.jar/d' %{name}-modules-doc.lang

%fdupes %{buildroot}%{_datadir}/%{name}/contrib/
%fdupes %{buildroot}%{_datadir}/%{name}/modules/
%fdupes %{buildroot}%{_datadir}/icons/hicolor/24x24/mimetypes/
# All scilab binaries in %%{_bindir} are essentially the same bash script, (hard) link them
%fdupes %{buildroot}%{_bindir}/

# FIXME: Disable tests until checkstyle and cobertura builds are fixed for openSUSE >= 13.1
# FIXME: Weird jvm crashes causes a test to fail, disable for openSUSE 12.3 also for now
%if 0%{?suse_version} < 1230
%check
echo $MALLOC_CHECK_
echo $MALLOC_PERTURB_
make check
%endif

%post -n %{soname}
/sbin/ldconfig

%postun -n %{soname}
/sbin/ldconfig

%post
%mime_database_post
%desktop_database_post
%icon_theme_cache_post

%postun
%mime_database_postun
%desktop_database_postun
%icon_theme_cache_postun

%files -n %{soname}
%defattr(-,root,root)
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so.*

%files
%defattr(-,root,root)
%doc ACKNOWLEDGEMENTS
%doc CHANGES_2.X CHANGES_3.X CHANGES_4.X CHANGES_5.0.X CHANGES_5.1.X CHANGES_5.2.X CHANGES_5.3.X CHANGES_5.4.X CHANGES_5.5.X
%doc RELEASE_NOTES_5.0.X RELEASE_NOTES_5.1.X RELEASE_NOTES_5.2.X RELEASE_NOTES_5.3.X
%doc README_Unix
%{_bindir}/*
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/etc/
%{_datadir}/%{name}/Version.incl
%{_datadir}/applications/*.desktop
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/%{name}/contrib
%{_datadir}/%{name}/tools
%dir %{_datadir}/appdata
%{_datadir}/appdata/scilab.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%files modules
%defattr(-,root,root)
%{_datadir}/%{name}/modules/
# part of scilab-doc
%exclude %{_datadir}/%{name}/modules/helptools/jar/%{name}_*.jar
%exclude %{_datadir}/%{name}/modules/*/examples
%exclude %{_datadir}/%{name}/modules/*/help
# part of scilab-tests
%exclude %{_datadir}/%{name}/modules/*/tests

%files modules-doc
%defattr(-,root,root)
%{_datadir}/%{name}/modules/*/examples
%{_datadir}/%{name}/modules/*/help
%{_datadir}/%{name}/modules/helptools/jar/%{name}_images.jar
%{_datadir}/%{name}/modules/helptools/jar/%{name}_en_US_help.jar

%files modules-doc-lang -f %{name}-modules-doc.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%doc COPYING license.txt
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf

%files tests
%defattr(-,root,root)
%{_datadir}/%{name}/modules/*/tests

%changelog
* Thu Aug  4 2016 badshah400@gmail.com
- Add scilab-hdf5-1_10-compat.patch to adapt code to HDF5 (>=
  1.10) and fix build failures.
- Add scilab-self-closing-br.patch to fix building with updated
  javadoc.
* Mon Jun 20 2016 olaf@aepfle.de
- BuildRequire ocaml.opt to avoid failure in bytecode-only projects
* Tue Jun 14 2016 olaf@aepfle.de
- Sources do not handle make -j N, remove _smp_mflags usage
* Wed Apr 13 2016 badshah400@gmail.com
- Add scilab-build-with-fop-2_1.patch to fix build failures when
  using xmlgraphics-fop >= 2.1 which has now landed in
  openSUSE:Factory; patch taken from upstream.
* Mon Mar 21 2016 normand@linux.vnet.ibm.com
- new scilab_ppc64le_java_archinstall_changed.patch
  to sync with java-1_8_0-openjdk sr #365892
- exclude ppc64 build as upstream still open bug
  http://bugzilla.scilab.org/show_bug.cgi?id=13826
* Tue Mar 15 2016 idonmez@suse.com
- Add scilab-batik-1.8.patch to fix build with Batik 1.8
* Mon Mar  7 2016 olaf@aepfle.de
- Remove timestamps from binaries
  scilab-timestamp.patch
* Fri Jan  8 2016 badshah400@gmail.com
- Remove scilab-disable-debian-specific-cflags.patch: This causes
  unforeseen issues (see e.g. http://bugzilla.scilab.org/14262)
  and the corresponding commit has also been reverted upstream.
* Mon Aug 31 2015 badshah400@gmail.com
- Apply scilab-build-with-xmlgraphics-commons-2_0.patch also for
  openSUSE:42 as it too has xmlgraphics-commons >= 2.0.
* Sun Jul 26 2015 badshah400@gmail.com
- Add scilab-disable-debian-specific-cflags.patch to disable
  cflags meant excl. for Debian.
* Tue May 26 2015 badshah400@gmail.com
- Build without external scirenderer; remove Requires and
  BuildRequires on external scirenderer which is discontinued as a
  standalone library by upstream.
* Thu Apr  9 2015 badshah400@gmail.com
- Use java-devel >= 1.8.0 for building, older java causes build
  failures.
* Thu Apr  2 2015 badshah400@gmail.com
- Update to version 5.5.2:
  + Release notes at
    http://www.scilab.org/community/news/20150401/release_notes.
- Requires jogl2 >= 2.2.4 to build.
- Add scilab-build-with-jogl-2.3.patch to make building with
  jogl and gluegen >= 2.3.0,
  http://bugzilla.scilab.org/show_bug.cgi?id=13809.
* Mon Mar  2 2015 sfalken@opensuse.org
- Added patch to fix desktop file categories, they were causing
  brp-check-suse failure in Factory.
  + Added: scilab-0003-fix-desktop-categories.patch
* Sat Jan 24 2015 badshah400@gmail.com
- Add scilab-build-with-xmlgraphics-commons-2_0.patch to fix
  compilation with xmlgraphics-commons >= 2.0
  (http://bugzilla.scilab.org/show_bug.cgi?id=13724).
* Thu Oct  2 2014 badshah400@gmail.com
- Update to version 5.5.1:
  + See release notes at
    http://www.scilab.org/index.php/community/news/20141002
- Remove upstreamed patches:
  + scilab-make-doc-ja_JP.patch
  + scilab-gluegen-path.patch
  + scilab-intg-crash.patch
  + scilab-fileio-hang-with-incorrect-format.patch
  + scilab-translation-build.patch
  + scilab-fix-arpack-detection.patch
  + scilab-pkconfig-use-system-tcltk-version.patch
- Rebase existing patches for current version.
* Fri Jul 18 2014 badshah400@gmail.com
- Add scilab-fileio-hang-with-incorrect-format.patch to fix
  scilab becoming unresponsive when incorrect format is specified
  for mfscanf; patch came from upstream; fixes
  http://bugzilla.scilab.org/13468.
* Tue Jul  8 2014 badshah400@gmail.com
- Add scilab-intg-crash.patch to fix scilab crash when intg
  involved division by zero; patch came from upstream; fixes
  http://bugzilla.scilab.org/13491 .
* Wed Jun 18 2014 badshah400@gmail.com
- Add scilab-fix-arpack-detection.patch to fix arpack-ng detection
  during compilation and enable arpack-ng bindings (fixes
  bnc#883233)
- Update scilab-fix-64bit-portability-issue.patch and
  scilab-pkconfig-use-system-tcltk-version.patch with those from
  upstream
- Comment out testng Requires from scilab-tests package; no
  longer seems necessary (testng is unmaintained in Java:packages
  anyway, so this has been a blocker for scilab's inclusion into
  Factory).
* Mon Apr 14 2014 badshah400@gmail.com
- Add scilab-translation-build.patch and
  scilab-make-doc-ja_JP.patch to fix building of lang package
- Enable lang package (building doc now requirs access to the
  X-server).
* Fri Apr 11 2014 badshah400@gmail.com
- Update to 5.5.0:
  + See list of changes since last stable version (5.4.1), see
    http://www.scilab.org/community/news/20140411/release_notes
- Packaging changes:
  + Drop patches (incorporated upstream):
  - scilab-fix-no-return-in-non-void.patch
  - scilab-build-with-jgraphx-2.5.patch
  - scilab-log-nan-plot-freeze.patch
  - scilab-crash-when-unreachable-url.patch
  - scilab-csv-read-crash.patch
  - scilab-datatip-precision.patch
  - scilab-fix-interactive-zoom.patch
  + Package non-english documentation for additional modules in
    a module-doc-lang package (reduces download size for eng
    users who would not need the additional languages)
  + Build "without-emf" as the required dependencies for building
    with emf are not packaged for openSUSE (and in all likelihood
    cannot be, since they depend on maven)
* Sun Mar 30 2014 badshah400@gmail.com
- Add scilab-pkconfig-use-system-tcltk-version.patch to fix
  compiler flags using hardcoded tcl/tk versions in scilab.pc
  instead of using version numbers from system tcl/tk versions
- Fix a couple more class-path-in-manifest rpmlint warnings.
* Thu Mar 13 2014 badshah400@gmail.com
- Add patches from upstream git to fix a few issues:
  + scilab-log-nan-plot-freeze.patch: to prevent scilab from
    freezing when used in some logscale plots involving %%nan;
    fixes http://bugzilla.scilab.org/13271
  + scilab-crash-when-unreachable-url.patch: fixes
    http://bugzilla.scilab.org/12948 - When host is not found,
    getURL provokes a Crash To Desktop
  + scilab-csv-read-crash.patch: fixes
    http://bugzilla.scilab.org/13186 - csvRead freezes if
    separator is empty string
  + scilab-datatip-precision.patch: fixes
    http://bugzilla.scilab.org/13258 - bad number display in
    datatips (minor rebase of upstream commit)
  + scilab-fix-interactive-zoom.patch: fixes
    http://bugzilla.scilab.org/12951 - interactive zooming in
    figures was broken.
* Tue Mar 11 2014 badshah400@gmail.com
- Update scilab-fix-no-return-in-non-void.patch with fixes from
  upstream git (fix includes fixes for fortran too); enable
  post-build-checks and remove corresponding rpmlintrc snippet
- Weird jvm crashes causes a test to fail, disable tests for
  openSUSE 12.3 also for now
- Proper ownership for %%{_libdir}/scilab directory.
* Tue Mar 11 2014 badshah400@gmail.com
- Split out a shared library package (libscilab5)
- scilab-devel now provides the header and shared object files
  needed for calling scilab from C/C++ programs; linking against
  Scilab also requires:
  + tcl-devel
  + pcre-devel
  + libxm2-devel
  + libSM-devel
  + ncurses-devel
- The main package scilab provides the scilab environment (both
  command-line and gui)
- Use fdupes to also link up files in %%{_bindir} -- these are
  essentially the same bash script.
* Sun Mar  9 2014 badshah400@gmail.com
- Add new patches:
  + Make building compatible with jgraphx >= 2.5.0.0; patch taken
    from upstream git; fixes http://bugzilla.scilab.org/13266
  + scilab-fix-64bit-portability-issue.patch: Fix compiler
    warnings w.r.t 64bit portability; fixes
    http://bugzilla.scilab.org/13267
  + scilab-fix-no-return-in-non-void.patch: Fix non-void functions
    returning random data (only cpp, fortran files not yet fixed,
    hence still disable post-build-checks); partly fixes
    http://bugzilla.scilab.org/13268
- Install scilab.conf file in %%{_sysconfdir}/ld.so.conf.d/so that
  ldconfig can find the shared libs
- Requires bwidget at run-time for the GUI
- Fix rpmlint warnings and errors as far as possible; comment to
  explain rpmlintrc usage when suppressing false positives.
* Sun Mar  9 2014 badshah400@gmail.com
- Update to version 5.5.0-beta-1:
  + Numerous changes; see
    /usr/doc/share/packages/scilab/CHANGES_5.5.X
  + Requires jgraphx >= 2.0.0.1, libcurl
  + Pass disable-static-system-lib to ./configure to prevent
    building and linking with static libs
- Rebase existing patches:
  + scilab-0001-Use-pkcon-to-install-doc-package.patch
  + scilab-0002-always-use-dynamic-stack.patch
  + scilab-gluegen-path.patch
- Drop unneeded patches:
  + scilab-0003-upgrade-to-matio-1.5.patch: incorporated upstream
- Add patches:
  + scilab-special-jarnames.patch: Adapt configure script to be
    able to find a few jar files with names exclusive to openSUSE
- Drop unnecessary externally bundled files:
  + patched_configure_script: use scilab-special-jarnames.patch
    to patch the configure script during building instead
  + patched_ImageExportRenderer.java: no longer needed
  + scilab.desktop, scinotes.desktop, xcos.desktop: correct
    "Categories" and install corresponding desktop files
    packaged in upstream tarball, instead, by using
    desktop-file-install
- Updated and new build/runtime dependecies:
  + libcurl-devel (build requirement)
  + jgraphx >= 2.0.0.1 (both build and runtime requirements).
* Sat Mar  8 2014 badshah400@gmail.com
- Use %%find_lang macro with %%{?no_lang_C} to ignore english lang
  files in lang_package and keep them in main package.
* Sat Mar  8 2014 badshah400@gmail.com
- Disable %%check section for openSUSE >= 13.1 until dependencies
  required specifically for this section (checkstyle, cobertura)
  are fixed and built; this should fix building on
  openSUSE >= 13.1 for now
- Use proper macros in the %%post(un) sections.
* Mon Sep 16 2013 dmitry_r@opensuse.org
- Fix path to gluegen2 library
  * scilab-gluegen-path.patch
* Sun Aug  4 2013 dmitry_r@opensuse.org
- Spec file cleanup
- Move modules to separate package
- Move localizations to separate package
* Thu Aug  1 2013 ierturk@ieee.org
- Update to version 5.4.1
  See included CHANGES_5.4.X for details
* Thu Jun 28 2012 scorot@free.fr
- update blas and lapack dependencies
* Thu Feb 23 2012 kkirill@opensuse.org
- addded scilab-5.3.2-allow-hdf-1.8.8.patch to fix Xcos start
  instead of scilab-5.3.2-allow-hdf-1.8.7.patch
* Tue Jul 26 2011 kirill.kirillov@gmail.com
- update to 5.3.3:
  + #9475 A mistake in the translation of a string was causing
    Scinotes to fail with the Japanese and Polish localizations
  + #9527 Problem when a text was exported in SVG from the GUI
  + #9545 contrib/loader.sce was no longer installed under Linux
* Mon Jun 20 2011 kirill.kirillov@gmail.com
- addded scilab-5.3.2-allow-hdf-1.8.7.patch to fix Xcos start
* Sun May 22 2011 kirill.kirillov@gmail.com
- updated to 5.3.2
* Tue Mar 29 2011 kirill.kirillov@gmail.com
- updated to 5.3.1
- dropped emacs support
* Thu May  6 2010 sylvestre.ledru@scilab.org
- emacs-nox => emacs-x11 to avoid a build issue
* Mon Mar 29 2010 kirill.kirillov@gmail.com
- added scilab-5.2.1-program-causes-undefined-operation.patch
- added scilab-5.2.1-pvm-spawn-process.patch
- added mime support (scilab-editor.desktop and scilab.xml)
* Sat Mar 13 2010 andrea@opensuse.org
- added scilab-5.2.1-implicit-fortify-decl.patch to fix
  implicit function declarations
* Thu Mar 11 2010 andrea@opensuse.org
- enable pvm modules
* Tue Feb  9 2010 sylvestre.ledru@scilab.org
- swig dep removed
- Author update
- other minor typo
* Sun Aug 16 2009 kirill.kirillov@gmail.com
- added scilab-5.1.1-gcc-undefined-situations.patch
- updated scilab-5.1.1-src-configure-path.patch to build against javahelp2 instead of jhall
- renamed gcc-checks.patch to scilab-5.1.1-gcc-implicit-definitions.patch
- other minor spec updates
* Tue Aug 11 2009 Andrea Florio <andrea@opensuse.org>
- added gcc-checks.patch to fix some post-build-checks errors
* Mon Aug 10 2009 Kirill Kirillov <kirill.kirillov@gmail.com>
- Added "export NO_BRP_CHECK_BYTECODE_VERSION=true" to %%install section
- Introduced .change file
* Wed Jun  3 2009 Andrea Florio <andrea@links2linux.de> 5.1.1 22.pm.0
- improved translations
- built docs
* Sun May 24 2009 Andrea Florio <andrea@links2linux.de> 5.1.1 21.pm.0
- new upstream version
* Thu Mar 19 2009 Andrea Florio <andrea@links2linux.de> 5.1 20.pm.0
- improved russian translation
* Tue Feb 24 2009 Andrea Florio <andrea@links2linux.de> 5.1 12.pm.7
- added more patches thanks to debian packagers
* Mon Feb 16 2009 Andrea Florio <andrea@links2linux.de> 5.1 10.pm.4
- new upstream version 5.1
- removed unsed patches (most of all accepted upstream)
- added new patches
* Sat Dec 20 2008 Andrea Florio <andrea@links2linux.de> 10.pm.2
- fixed java-export path, now it will export /etc/alternatives (arch indipendent)
* Mon Dec 15 2008 Andrea Florio <andrea@opensuse.org> 10.pm.1
- added patches to fix bugs http://bugzilla.scilab.org/show_bug.cgi?id=3860
  java-devel no more required
* Sun Dec 14 2008 Andrea Florio <andrea@opensuse.org>
- added patch: scilab-5.0.3-src-libfftw3-fixed-link.patch
  fftw3-devel no more required
* Sat Dec 13 2008 Andrea Florio <andrea@opensuse.org>
- added patch fix bug http://bugzilla.scilab.org/show_bug.cgi?id=3854
- fixed "Requires" : added xmlgraphics-commons
  and fftw3-devel (scilab requires /usr/lib/libfftw3.so)
* Mon Dec  8 2008 andrea@opensuse.org
- new upstream version 5.0.3
- ported all patches on new version
- fixed lots of stuffs, added help
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Jul  1 2008 andrea@opensuse.org
- fixed package, now build on openSUSE 11.0
* Wed Nov 21 2007 sylvestre.ledru@inria.fr
- Dep to imagemagick removed
- Description updated
- problem with the autoconf patch fixed
* Tue Nov 20 2007 sylvestre.ledru@inria.fr
- Fix autoconf problem for SLE_10, SUSE_Linux_10.0 and SUSE_Linux_10.1
- URL updated
* Sat Nov  3 2007 lars@linux-schulserver.de
- update to 4.1.2:
  Editor:
  + Windows style editing: basic operations implemented.
  + Multi-diagram editing: for example copy and paste from any
    window to any other.
  + Documentation: fairly complete on-line help and supporting
    documentation.
  + Active Scilab prompt: menu activated.
  + Undo operation: one step per window.
  + Diagram browser: a much nicer replacement for the old navigator
* Wed Oct 24 2007 lars@linux-schulserver.de
- removed the following patches:
  scilab-overflow.patch
  scilab-4.1.1.src-intslicot.patch
  scilab-4.1.1.src-gfortran.patch
  scilab-4.1.1.src-gcc_warnings-fix.patch
  scilab-4.1.1.src-fortran_warnings-fix.patch
  scilab-4.1.1.pvm3_src_make_aimk.patch
  scilab-4.1.1-implicit_decl.patch
  scilab-4.1.1-compiler.patch
- fixes (os-edu #0000005)
* Tue Jul 24 2007 lrupp@suse.de
- added desktop file
* Fri Jul 20 2007 lrupp@suse.de
- update to 4.1.1
* Wed Nov 22 2006 olh@suse.de
- package was enabled by accident for ppc64 (223247)
* Sat Nov 11 2006 olh@suse.de
- find fortran compiler also on powerpc-linux
  fix undefined behaviour in intab01od()
* Fri Aug  4 2006 lmichnovic@suse.cz
- now builds also with X.org 7.x; detecting prefix in X.org
* Fri Jul 28 2006 anicka@suse.cz
- update to 4.0
  * major release with plenty of new features
  * improvement of graphic environment
  * new interface for Excel
  * try-catch instruction added
  * improvements in Matlab to Scilab converter
- added fixes for implicit declarations, uninitialized
  variables and buffer overflow in string buffers new
  in thus version
- change sed  script editing configure.in in specfile
* Sat Apr  8 2006 schwab@suse.de
- Fix reference to libgfortran internal names.
- Don't link against libf2c and remove f2c from BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Thu Oct 13 2005 postadal@suse.cz
- fix security hole by wrongly initializing LD_LIBRARY_PATH
  [#118188] (secure-paths.patch)
* Mon Sep 26 2005 ro@suse.de
- fix some implicit declarations
* Wed Aug 10 2005 pnemec@suse.cz
- fix fortran warnings
- added rpmOptsFlag in makefiles
- fix installation of help files
* Wed Aug 10 2005 ro@suse.de
- fix some more warnings
* Fri Aug  5 2005 pnemec@suse.cz
- update to 3.1.1
- fixed gcc warnings
* Fri May 13 2005 meissner@suse.de
- fixed bufferoverflows in string buffers.
* Wed May  4 2005 postadal@suse.cz
- removed parallel make (some time does not work well)
* Fri Apr 29 2005 postadal@suse.cz
- updated to version 3.1rc1
- fixed for gcc 4.0
- use parallel make
* Thu Feb 24 2005 postadal@suse.cz
- ExclusiveArch for 32bit archs: %%%%ix86 s390 ppc (does not work on 64bit archs,
  a lot of portable problems [#64748], [#64054])
- fixed functions which returned random data (gcc_warnings-fix)
* Thu Dec  2 2004 postadal@suse.cz
- added sablot to #neededforbuild (needs documentation) [#48257]
- added missing files for compiling examples [#48679]
- added ocaml to #neededforbuild (enables the Modelica compiler)
* Thu Aug 26 2004 postadal@suse.cz
- removed precompiled binaries from examples (caused bad dependencies [#44132])
* Mon Aug 23 2004 postadal@suse.cz
- removed libraries packed to documentation
* Mon Aug  9 2004 postadal@suse.cz
- updated to version 3.0
- merged configure patches in the one
* Fri Mar 19 2004 postadal@suse.cz
- removed useless files (*.orig)
* Fri Mar  5 2004 postadal@suse.cz
- compile with -fno-strict-aliasing
- removed f2c from neededforbuild flag
* Fri Feb 27 2004 postadal@suse.cz
- fixed building on s390*
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Tue Aug 19 2003 ro@suse.de
- fixed lib64 problem
* Wed Aug 13 2003 postadal@suse.cz
- fixed link to help pages [#27827] and permissions [#28641]
* Mon Jul 28 2003 ro@suse.de
- added tk-devel to neededforbuild
* Fri Jun  6 2003 mmj@suse.de
- Remove dangling symlinks
* Mon Jun  2 2003 ro@suse.de
- remove .cvsignore files
* Mon Feb 17 2003 postadal@suse.cz
- updated to version 2.7
  * linear algebra primitives now based on Lapack instead of Linpack/Eispack
  * hypertext, xml based, online help
  * added binary Matlab file .mat loader (loadmatfile)
  * slicot based control routines
  * interface with TeXmacs
  * embedded text editor scipad derived from TkNotepad
* Mon Feb  3 2003 meissner@suse.de
- fixed almost all varargs.h -> stdarg.h problems.
  Some still left, but these are in the examples.
- Use $RPM_OPT_FLAGS.
* Tue Sep 24 2002 postadal@suse.cz
- fixed config for ppc64 (powerpc -> ppc)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 15 2002 postadal@suse.cz
- fix packaging (added dir man/strings, bug #17603)
* Tue Jun 18 2002 mls@suse.de
- delete bogus config.status file
* Thu Jun  6 2002 postadal@suse.cz
- fixed for lib64 paths
* Tue May 21 2002 ro@suse.de
- fix configure for x86_64
* Wed Mar 13 2002 pmladek@suse.cz
- fixed file permissions
- fixed headers of shell scripts
* Tue Jun 12 2001 cihlar@suse.cz
- fixed to compile with new autoconf
* Fri Apr 20 2001 cihlar@suse.cz
- fixed to compile on s390 and axp
* Tue Apr  3 2001 cihlar@suse.cz
- update to version 2.6
* Tue Mar 20 2001 cihlar@suse.cz
- fixed call of suse_update_config
* Tue Feb 20 2001 cihlar@suse.cz
- fixed to compile on axp and ia64
* Fri Jan 19 2001 cihlar@suse.cz
- added directories examples, imp, pvm3, routines
- compile with --with-tk
* Wed Nov 15 2000 cihlar@suse.cz
- bzipped sources
- fixed copyright tag
- fixed file list
* Wed May 17 2000 cihlar@suse.cz
- removed /usr/doc/packages
* Mon Apr 17 2000 cihlar@suse.cz
- fixed to compile on sparc
* Thu Apr 13 2000 cihlar@suse.cz
- added autoconf
- fixed to compile
* Sun Apr  9 2000 bk@suse.de
- added suse update config macro
- added automake to the list of packages needed for building scilab
* Tue Mar 14 2000 cihlar@suse.cz
- removed Makefile.Linux
- added BuildRoot
* Wed Feb  2 2000 fehr@suse.de
- fixes to build on alpha and sparc
* Thu Jan 13 2000 fehr@suse.de
- changed to new version 2.5
* Mon Oct 18 1999 ro@suse.de
- fixed neededforbuild
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri May 21 1999 ro@suse.de
- fixed to build on alpha and with glibc-2.1
* Wed Mar 17 1999 ro@suse.de
- remove .orig with -f
* Sun Dec 20 1998 bs@suse.de
- use egcs for build
* Wed Nov 25 1998 ro@suse.de
- fixed to build with glibc
* Wed Dec  3 1997 ro@suse.de
- fixed start-script (executable-flags)
* Mon Nov 17 1997 ro@suse.de
- removed .orig's
* Wed Oct 29 1997 bs@suse.de
- fixed scripts (dold & scilab.g)
* Fri Oct 24 1997 fehr@suse.de
- prepare package for automatic build
- switched to new version 2.3.1
* Thu Jun 26 1997 fehr@suse.de
- add file /usr/lib/scilab/imp/NperiPos.ps to package
* Mon Jun  9 1997 fehr@suse.de
- make symbolic links realtive
